
#ifndef _XSECDEFS_H_
#define _XSECDEFS_H_

#if SEC_BASE

/*
 * Copyright (c) SecureWare, Inc, 1994, All rights reserved.
 *
 * @(#)02 1.5 x11r5/extensions/include/xsecurity/Xsecdefs.h, xsecext, sco_3.0, 301FCS 14:26:40 1/2/95, SecureWare, Inc.
 */

#include <X11/extensions/Xsecos.h>

/* Extension name */

#define XSECURITYNAME "XSecurity"

/*
 * Event numbers / event selection masks.
 */
#define	InactivityTimeoutEvent		0	/* Must add security ext. */
#define	SelectionRedirectEvent		1	/* event base to these */
#define	SelectionForwardNotifyEvent	2
#define	ServiceNotifyEvent		3
#define	AttributeNotifyEvent		4
#define	GrabOverrideNotifyEvent		5
#define ClearResetNotifyEvent		6
#define ScreenNotifyEvent		7

#define		LastSecEvent			7

#define	InactivityTimeoutMask		0x01
#define	SelectionRedirectMask		0x02
#define	ServiceNotifyMask		0x04
#define	AttributeNotifyMask		0x08
#define	GrabOverrideNotifyMask		0x10
#define ClearResetNotifyMask		0x20
#define	ScreenNotifyMask		0x40

#define	LastSecEventMask			0x40


/*
 * ServiceNotify detail values.
 */
#define	Registered			1
#define	Unregistered			2
#define	ConnectionLost			3
#define	ReRegistered			4


/*
 * GrabOverrideNotify detail values.
 */
#define ServerGrab      0x01
#define PointerGrab     0x02
#define KeyboardGrab    0x04

/*
 * Types of access a subject may make to an object:
 */
#define	AccessManage		0
#define	AccessInsert		1
#define	AccessQuery		2
#define	AccessWrite		3
#define AccessRead		4

/*
 * OR'd into to the access type when checking ability to change security
 * attributes.
 */
#define	AccessOwnerOnly		0x10000

/*
 * DAC permission definitions.
 */

#define	DACRead			(1 << AccessRead)
#define	DACWrite		(1 << AccessWrite)
#define	DACQuery		(1 << AccessQuery)
#define	DACInsert		(1 << AccessInsert)
#define	DACManage		(1 << AccessManage)

#define DACNone			(0)
#define DACAll			(DACRead | DACWrite | DACInsert |	\
				DACQuery | DACManage)

#define DACUserShift		16
#define DACGroupShift		8
#define DACOtherShift		0

/*
 * Privilege definitions.
 */
#define XPrivDACRead		0
#define XPrivDACWrite		1
#define XPrivDACOwner		2
#if SEC_MAC
#define XPrivMACRead		3
#define XPrivMACWrite		4
#define XPrivMACDowngrade	5
#define XPrivMACUpgrade		6
#define XPrivMACWriteup		7
#define XPrivMACMultilevel	8
#endif /* SEC_MAC */
#define XPrivWMTrustedPath	9
#define XPrivWMFunction		10
#define XPrivXSetAccessControl  11
#define XPrivXSetDeviceControl  12
#define XPrivXTrustedFunction	13
#if SEC_ILB
#define XPrivILBDowngrade	14
#define XPrivILBUpgrade		15
#define XPrivILBClientNofloat	16
#define XPrivILBObjectNofloat	17
#endif
#define	XPrivXSuspendAudit	18

#	define X_NUM_PRIVILEGES		19

/*
 * Size of a privilege set.
 */

#define X_PRIVSET_SIZE			2	/* (Long words) */

/*
 * These macros are used to manipulate privileges and privilege sets.
 */

#define	PrivAddToSet(set, p)	(set)[(p) / PRIVWORD_SIZE] |= \
				 1 << ((p) % PRIVWORD_SIZE)

#define	PrivRmFromSet(set, p)	(set)[(p) / PRIVWORD_SIZE] &= \
				 ~(1 << ((p) % PRIVWORD_SIZE))

#define PrivIsInSet(set, p)	((set)[(p) / PRIVWORD_SIZE] & \
				 (1 << ((p) % PRIVWORD_SIZE)))


/* X Server audit record event types */

#define	XAuditClientCreate			1
#define	XAuditClientDelete			2
#define	XAuditObjectCreate			3
#define	XAuditObjectDelete			4
#define	XAuditObjectModify			5
#define	XAuditDACAccessOverride			6
#define	XAuditMACReadAccessOverride		7
#define	XAuditMACWriteAccessOverride		8
#define	XAuditDACOwnerAccessDenial		9
#define	XAuditDACManageAccessDenial		10
#define	XAuditDACQueryAccessDenial		11
#define	XAuditDACInsertAccessDenial		12
#define	XAuditDACReadAccessDenial		13
#define	XAuditDACWriteAccessDenial		14
#define	XAuditMACReadAccessDenial		15
#define	XAuditMACWriteAccessDenial		16
#define	XAuditUseOfPrivilege			17
#define	XAuditLackOfPrivilege			18
#define	XAuditClientNofloat			19
#define	XAuditObjectNofloat			20
#define	XAuditObjectUIDChange			21
#define	XAuditObjectGIDChange			22
#define	XAuditObjectModeChange			23
#define	XAuditObjectMACLabelChange		24
#define	XAuditObjectInfoLabelChange		25
#define	XAuditObjectInputInfoLabelChange	26

#if SEC_MAC

/*
 * Possible values for the Multilevel property "compose mode".
 */
#define Compose			0
#define NoCompose		1

/*
 * Possible values for the Multilevel property "mac label type"
 */
#define ClientLevel		0
#define ExplicitLevel		1
#define MultiLevel		2

#endif /* SEC_MAC */


/*
 * Values for whichSet in {G,S}etDefaultPermissions.
 */

#define	PrivatePerms		0
#define	GlobalPerms		1

/*
 * Values for 'family' in  {G,S}etDisplayACL
 */

#define WILDCARD_HOST		-1
#define WILDCARD_USER		-1

/*
 * Values for 'access' in {G,S}etDisplayACL
 */

#define ACCESS_DENIED		0
#define ACCESS_GRANTED		1

#endif	/* SEC_BASE */
#endif	/* _XSECDEFS_H_ */
